@@ -119,7 +119,7 @@ class BaseField(object):
         self.custom = custom
         self.primary_key = primary_key
         self.db_only = db_only
-        self.context = context
+        self.context = {} if context is None else context
 
         # These are set up by `.bind()` when the field is added to a serializer.
         self.field_name = None
